@@ -161,8 +161,9 @@ import typing_extensions
 
 from ._jsii import *
 
+import aws_cdk
 import aws_cdk.aws_iam
-import aws_cdk.core
+import constructs
 
 
 class GithubActionsRole(
@@ -192,7 +193,7 @@ class GithubActionsRole(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         owner: builtins.str,
@@ -203,7 +204,7 @@ class GithubActionsRole(
         external_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
         inline_policies: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_iam.PolicyDocument]] = None,
         managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
-        max_session_duration: typing.Optional[aws_cdk.core.Duration] = None,
+        max_session_duration: typing.Optional[aws_cdk.Duration] = None,
         path: typing.Optional[builtins.str] = None,
         permissions_boundary: typing.Optional[aws_cdk.aws_iam.IManagedPolicy] = None,
         role_name: typing.Optional[builtins.str] = None,
@@ -423,7 +424,7 @@ class RoleProps:
         external_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
         inline_policies: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_iam.PolicyDocument]] = None,
         managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
-        max_session_duration: typing.Optional[aws_cdk.core.Duration] = None,
+        max_session_duration: typing.Optional[aws_cdk.Duration] = None,
         path: typing.Optional[builtins.str] = None,
         permissions_boundary: typing.Optional[aws_cdk.aws_iam.IManagedPolicy] = None,
         role_name: typing.Optional[builtins.str] = None,
@@ -516,7 +517,7 @@ class RoleProps:
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_iam.IManagedPolicy]], result)
 
     @builtins.property
-    def max_session_duration(self) -> typing.Optional[aws_cdk.core.Duration]:
+    def max_session_duration(self) -> typing.Optional[aws_cdk.Duration]:
         '''The maximum session duration that you want to set for the specified role.
 
         This setting can have a value from 1 hour (3600sec) to 12 (43200sec) hours.
@@ -537,7 +538,7 @@ class RoleProps:
         :link: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html
         '''
         result = self._values.get("max_session_duration")
-        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+        return typing.cast(typing.Optional[aws_cdk.Duration], result)
 
     @builtins.property
     def path(self) -> typing.Optional[builtins.str]:
@@ -617,7 +618,7 @@ class GithubActionsIdentityProvider(
     :stability: experimental
     '''
 
-    def __init__(self, scope: aws_cdk.core.Construct, id: builtins.str) -> None:
+    def __init__(self, scope: constructs.Construct, id: builtins.str) -> None:
         '''(experimental) Define a new Github OpenID Connect Identity PRovider for AWS IAM.
 
         There can be only one (per AWS Account).
@@ -637,7 +638,7 @@ class GithubActionsIdentityProvider(
     @builtins.classmethod
     def from_account(
         cls,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
     ) -> IGithubActionsIdentityProvider:
         '''(experimental) Retrieve a reference to existing Github OIDC provider in your AWS account.
@@ -706,7 +707,7 @@ class GithubActionsRoleProps(GithubConfiguration, RoleProps):
         external_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
         inline_policies: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_iam.PolicyDocument]] = None,
         managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.IManagedPolicy]] = None,
-        max_session_duration: typing.Optional[aws_cdk.core.Duration] = None,
+        max_session_duration: typing.Optional[aws_cdk.Duration] = None,
         path: typing.Optional[builtins.str] = None,
         permissions_boundary: typing.Optional[aws_cdk.aws_iam.IManagedPolicy] = None,
         role_name: typing.Optional[builtins.str] = None,
@@ -884,7 +885,7 @@ class GithubActionsRoleProps(GithubConfiguration, RoleProps):
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_iam.IManagedPolicy]], result)
 
     @builtins.property
-    def max_session_duration(self) -> typing.Optional[aws_cdk.core.Duration]:
+    def max_session_duration(self) -> typing.Optional[aws_cdk.Duration]:
         '''The maximum session duration that you want to set for the specified role.
 
         This setting can have a value from 1 hour (3600sec) to 12 (43200sec) hours.
@@ -905,7 +906,7 @@ class GithubActionsRoleProps(GithubConfiguration, RoleProps):
         :link: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html
         '''
         result = self._values.get("max_session_duration")
-        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+        return typing.cast(typing.Optional[aws_cdk.Duration], result)
 
     @builtins.property
     def path(self) -> typing.Optional[builtins.str]:
