@@ -8,15 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_iam._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "aws-cdk-github-oidc",
-    "1.0.0",
+    "2.0.0",
     __name__[0:-6],
-    "aws-cdk-github-oidc@1.0.0.jsii.tgz",
+    "aws-cdk-github-oidc@2.0.0.jsii.tgz",
 )
 
 __all__ = [
